Core Concepts

## Introduction
Kubernetes includes out of the box crucial production clustering capabilities to make running containers easier.
  - Kubernetes can relocate apps without manual intervention
  - Self healing capabilities
  - Declarative deployments

## Roles
In Kubernetes, there are a two roles that a node can be within a cluster. 
These roles are:
  - Master - A cluster can have one or many master nodes
	  - Master nodes can only manage the cluster and are not worker nodes to run workloads
  - Worker - A cluser can have zero or many worker nodes
	  - These run pods and services
	  - Can run thousands of worker nodes and the workflow is the same as if you are running on one node

  
The components of the different roles are as follows:

* Master server
  - API server which is a communication hub for the cluster
  - Scheduler which assigns apps to worker node(s)
  - Controller Manager maintains the cluster, system services, etc
  - etcd stores cluster configuration
	  - It is *highly* recommended to back this up
  - Master server can and *should* be replicated
* Worker node
	- kubelet talks with API server to run and manage containers
	- kube-proxy load balances between app components
	- container-runtime is what runs the actual containers (docker, rkt, containerd, etc)

## Administration

* All kubernetes system components communicate with the API server only
* API server is the only one that talks directly with etcd, everything else goes through the API server


## Manifest Declaration

Example NGINX declaration:
```yaml
apiVersion: apps/v1
kind: Deployment
metadata:
  name: nginx-deployment
spec:
  selector:
    matchLabels:
      app: nginx
  replicas: 2
  template:
    metadata:
      labels:
        app: nginx
    spec:
      containers:
        - name: nginx
          image: nginx:1.7.9
          ports:
            - containerPort: 80
```

`spec` defines the declarative specification of what the object should look like

If the status and spec do not match, the control plane will correct it and make it match again



## Command Reference

Action | Command
--- | ---
Get nodes in cluster | `kubectl get nodes`
Get pods in cluster w/ node info | `kubectl get pods --all-namespaces -o wide`
Get status of system components | `kubectl get componentstatus`
Get deployment information      | `kubectl get deployment <deployment_name> -o yaml`




















id: 3ca2fc56fd5549eca1af5cfd4ad1534f
parent_id: e92b8e344244403a8768e5d9ace262a8
created_time: 2020-05-07T22:55:39.530Z
updated_time: 2020-05-08T02:24:12.948Z
is_conflict: 0
latitude: 15.69720000
longitude: 100.13790000
altitude: 0.0000
author: 
source_url: 
is_todo: 0
todo_due: 0
todo_completed: 0
source: joplin-desktop
source_application: net.cozic.joplin-desktop
application_data: 
order: 0
user_created_time: 2020-05-07T22:55:39.530Z
user_updated_time: 2020-05-08T02:24:12.948Z
encryption_cipher_text: 
encryption_applied: 0
markup_language: 1
is_shared: 0
type_: 1